
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef GEKGPRINTDIALOG_H
#define GEKGPRINTDIALOG_H
#include <unistd.h>
#include <pwd.h>
#include <sys/types.h>
#include <cstdlib>
#include <list>
#include <gtk--/base.h>
#include <gtk--/box.h>
#include <gtk--/button.h>
#include <gtk--/buttonbox.h>
#include <gtk--/checkbutton.h>
#include <gtk--/combo.h>
#include <gtk--/dialog.h>
#include <gtk--/entry.h>
#include <gtk--/label.h>
#include <gtk--/separator.h>
#include <gtk--/table.h>

using SigC::slot;

/**
 * Druckdialog fr ein EKG.
 * Im Dialog wird eine Spannungsskalierung (2,5; 5; 10; 20 mm/mV) und eine
 * Zeitskalierung (5; 10; 25; 50 mm/s) gewhlt. Es wird ein Drucker-
 * oder Dateiname erfragt und ob in eine Datei gedruckt werden soll.
 * Auerdem Werden Parientendaten (Name und Geb. Datum) eingegben.
 * <p>
 * Die Erfragten Werte knnen ber public Felder gelesen werden. In state
 * ist vermerkt, ob OK oder Cancel gedrckt wurde.
 *
 * @author Lars Stollenwerk, Jannuar 2003
 */
class gEKGPrintDialog : public Gtk::Dialog
{
  public:
    /// Konstruktor
    gEKGPrintDialog();
    /// Zeitskala in mm/s
    float ts;
    /// Spannungsskala in mm/mV
    float vs;
    /// Als Datei Speichern?
    bool toFile;
    /// Datei- oder Druckername
    string fname;
    /// Name des Patienten
    string pname;
    /// Geb. Datum des Patienten
    string pdate;
    /// true = OK, false = Cancel
    bool state;

    /// Gibt OK Button zurck. So knnen Signale angeschlossen werden.
    Gtk::Button * get_ok_button() { return & OKButton; }
    /// Gibt Cancel Button zurck. So knnen Signale angeschlossen werden.
    Gtk::Button* get_cancel_button() { return & CButton; }

  private:
    //
    // Gtk Objekte
    //
    
    /// Auswahl Zeitskala
    Gtk::Combo tCombo;
    /// Auswahl Spannungsskala
    Gtk::Combo vCombo;
    /// Auswahl in Datei
    Gtk::CheckButton tfCButton;
    /// Eingabe Datei/Drukername
    Gtk::Entry fName;
    /// OK Button
    Gtk::Button OKButton;
    /// Cancel Button
    Gtk::Button CButton;
    /// Eingabe Patientenname
    Gtk::Entry pName;
    /// Eingabe Patienten Geburtsdatum
    Gtk::Entry pDate;

    /// Label Zeitskala
    Gtk::Label tLabel;
    /// Label Spannung
    Gtk::Label vLabel;
    /// Label file name
    Gtk::Label nLabel;
    /// Label Patienten Name
    Gtk::Label pnLabel;
    /// Label Patienten Geburtsdatum
    Gtk::Label pdLabel;

    Gtk::HSeparator separator;
    Gtk::HButtonBox bBox;
    Gtk::Table table;

    //
    // Methoden
    //

    /// Fenster wird beim schlieen nicht zerstrt.
    int delete_event_impl(GdkEventAny *event) 
      { Ccallback(); return true; }
    /// Bei OK alle Daten bernehmen.
    void OKcallback();
    /// Bei Cancel state = false und sonst nix.
    void Ccallback();
    /// Tastendrcke
    gint keyCallback( GdkEventKey * e );
};

#endif

