
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "gEKGfreq.h"
#include "heart_bg.xpm"
#include "heart_sm.xpm"

/* Konstruktor */
gEKGfreq::gEKGfreq() : hBox(false,0), Pulse("Pulse"),
                       Heart_bg(heart_bg_xpm), Heart_sm(heart_sm_xpm), 
		       Hcount(0)
{
  // Aussehen
  frame.set_shadow_type( GTK_SHADOW_ETCHED_IN );
  add( frame );
  frame.add( hBox );
  hBox.pack_start( Pulse, false, false, 2 );
  hBox.pack_end( Heart_sm, false, false, 2 );
  // Pipe zur Prozekommunikation
  if ( 0 != pipe( Pipe ) ) 
    throw string("gEKGfreq::gEKGfreq() : Can't open pipe.");
  Gtk::Main::input.connect( slot( this, &gEKGfreq::drawRealtime ), 
                            Pipe[0], GDK_INPUT_READ );

}



/* Hcount herunterzhlen */
void gEKGfreq::input( float * d )
{
  EKGfreq::input( d );
  if ( Hcount == 0 ) return; 
  Hcount--;
  if ( Hcount != 0 ) return;
  const int i = -1; // -1 in pipe = Herz aus
  if ( psize != write( Pipe[1], &i, psize ) )
    throw string("gEKGfreq::input() : Can't write psize bytes to pipe.");
}

/* kleines Herz zeigen */
void gEKGfreq::reset()
{
  if ( Heart_bg.is_visible() )
  {
    Heart_bg.hide();
    hBox.remove( Heart_bg );
    hBox.pack_end( Heart_sm, false, false, 2 );
    Heart_sm.show();
  }
}

// ----------------------------------------------------------------------
//
// private Methoden
// 
// ----------------------------------------------------------------------

/* Pusfrequenz verarbeiten */
void gEKGfreq::handleQRS()
{
  EKGfreq::handleQRS();
  Hcount = static_cast<int>( Htime / EKG_TimeStep );
  if ( psize != write( Pipe[1], &freq, psize ) )
    throw string("gEKGfreq::handleQRS() : Can't write psize bytes to pipe.");
}



/* Aktualisieren der Anzeige */
void gEKGfreq::drawRealtime( gint fd, GdkInputCondition /* not used */ )
{
  // Daten von Pipe holen
  int f;
  if ( psize != read( fd, &f, psize ) )
    throw string("gEKGfreq::drawRealtime() : Can't get psize bytes.");
  if ( f < 0 ) // Herz aus
  {
    Heart_bg.hide();
    hBox.remove( Heart_bg );
    hBox.pack_end( Heart_sm, false, false, 2 );
    Heart_sm.show();
  }
  else // Label aktualisieren, Herz an
  {
    ostringstream os;
    os << f << ends;
    Pulse.set_text( os.str() );
    if ( Heart_sm.is_visible() )
    {
      Heart_sm.hide();
      hBox.remove( Heart_sm );
      hBox.pack_end( Heart_bg, false, false, 2 );
      Heart_bg.show();
    }
  }
}


